utils

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 20, 2023 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ContainsString

func ContainsString(slice []string, str string) bool

containsString function checks if a string is present in a slice

func FormatHumanDate

func FormatHumanDate(dateTime time.Time) string

func FormatSize

func FormatSize(size int64) string

func GenerateRandomString

func GenerateRandomString(length int) string

generateRandomString generates a random string of the specified length

func RenameFileToUnique

func RenameFileToUnique(filename string) string

func SplitFile

func SplitFile(filename string) (string, string)

Split the file in basename and extension

Types

This section is empty.

Jump to