Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ContainsString ¶
containsString function checks if a string is present in a slice
func FormatHumanDate ¶
func FormatSize ¶
func GenerateRandomString ¶
generateRandomString generates a random string of the specified length
func RenameFileToUnique ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.